# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .song import Song
from .._models import BaseModel

__all__ = ["SongCreateResponse"]


class SongCreateResponse(BaseModel):
    song: Optional[Song] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .song import Song
from .._models import BaseModel

__all__ = ["SongListResponse", "Pagination"]


class Pagination(BaseModel):
    limit: Optional[int] = None

    page: Optional[int] = None

    total: Optional[int] = None

    total_pages: Optional[int] = FieldInfo(alias="totalPages", default=None)


class SongListResponse(BaseModel):
    pagination: Optional[Pagination] = None

    songs: Optional[List[Song]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .songs import (
    SongsResource,
    AsyncSongsResource,
    SongsResourceWithRawResponse,
    AsyncSongsResourceWithRawResponse,
    SongsResourceWithStreamingResponse,
    AsyncSongsResourceWithStreamingResponse,
)

__all__ = [
    "SongsResource",
    "AsyncSongsResource",
    "SongsResourceWithRawResponse",
    "AsyncSongsResourceWithRawResponse",
    "SongsResourceWithStreamingResponse",
    "AsyncSongsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .song import Song as Song
from .song_list_params import SongListParams as SongListParams
from .song_create_params import SongCreateParams as SongCreateParams
from .song_list_response import SongListResponse as SongListResponse
from .song_create_response import SongCreateResponse as SongCreateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["SongCreateParams"]


class SongCreateParams(TypedDict, total=False):
    prompt: Required[str]
    """Text prompt for song generation (max 200 characters)"""

    genre: str
    """Musical genre"""

    is_instrumental: Annotated[bool, PropertyInfo(alias="isInstrumental")]
    """Whether the song should be instrumental.

    If the song is instrumental, the lyrics will be ignored.
    """

    lyrics: str
    """Optional lyrics for the song.

    If not provided, the prompt will be used to generate lyrics.
    """

    mood: str
    """Mood of the song"""
